# This Python program creates templates for FreeCad TechDraw drawings
# according to ISO 5457 and IS 7200 rules. More less.
#
# coding: UTF-8
#
# Author: Martin Prokš
# e-mail: martin.proks@proks-martin.cz
# License:  Free to use without limitations
# Date: 11/2023
# Created from scratch for FreeCAD project


# Global modules imports
# **********************
import math
import sys


# Subroutine for command line help
# ********************************
def help_report ():
    print ("Usage: python template_maker.py A4 mm 210 297 \"John Doe\" \"Street ...\" \"City ...\" \"e-mail ...\"")
    print ("  or: python template_maker.py A4 mm 210 297 \"John Doe\" \"Street ...\" \"City ...\" \"e-mail ...\" > A4_template.svg")
    print ("  or: python template_maker.py A3 mm 420 297 \"John Doe\" \"Street ...\" \"City ...\" \"e-mail ...\" > A3_template.svg")
    print ("  or: python template_maker.py A3.2 mm 594 297 \"John Doe\" \"Street ...\" \"City ...\" \"e-mail ...\" > A3.2_template.svg")
    print ("  ...")
    print ("Create templates for FreeCad TechDraw drawings")
    print ("according to ISO 5457 and IS 7200 rules. More less.")
    print ("")
    print ("Mandatory arguments:")
    print ("  mark of paper format (A4, ... A0)")
    print ("  paper units (mm)")
    print ("  paper width")
    print ("  paper height")
    print ("  legal owner - 1st line")
    print ("  legal owner - 2nd line")
    print ("  legal owner - 3th line")
    print ("  legal owner - 4th line")
    print ("")
    print ("Optional arguments:")
    print ("  help | -help | --help | ? | -? | --?   : this help report")
    print ("")
    print ("Output (template) is written to the standard output stream.")
    print ("Template is a SVG file (XML)")
    print ("")
    print ("ISO 5457 standard formats are:")
    print ("")
    print ("  A4 mm 210 297")
    print ("  A3 mm 420 297")
    print ("  A2 mm 594 420")
    print ("  A1 mm 841 594")
    print ("  A0 mm 1189 841")
    print ("  A3.2 mm 594 297")
    print ("  A3.1 mm 841 297")
    print ("  A3.0 mm 1189 297")
    print ("  A2.1 mm 841 420")
    print ("  A2.0 mm 1189 420")
    print ("  A1.0 mm 1189 594")
    print ("")
    print ("Author: Martin Prokš")
    print ("e-mail: martin.proks@proks-martin.cz")
    print ("License: Free to use without limitations")
    print ("Date: 11/2023")
    print ("Created from scratch for FreeCAD project")


# Subroutines and functions for paper borders
# *******************************************
def corner_mark (mark_comment, mark_construction):
    print ("  <!-- " + mark_comment + " -->")
    print ("  <path")
    print ("    style=\"fill:#000000;fill-opacity:1;stroke:#000000;stroke-width:0.0;"\
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"")
    print ("    d=\"" + mark_construction + "\" />")
    
def borders_of_drawing_area (x1, y1, x2, y2, width, comment):
    print ("  <!-- " + comment + " -->")
    print ("  <path")
    print ("    style=\"fill:#ffffff;fill-opacity:1;stroke:#000000;stroke-width:{};"\
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"".\
           format(width))
    print ("    d=\"M{0} {1} L{2} {1} L{2} {3} L{0} {3} Z\" />".format(x1, y1, x2, y2))

def center_mark (comment, mark_construction):
    print ("  <!-- " + comment + " -->")
    print ("  <path")
    print ("    style=\"fill:#ffffff;fill-opacity:1;stroke:#000000;stroke-width:0.7;"\
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"")
    print ("    d=\"" + mark_construction + "\" />")

def delimiter_of_sectors (x1, y1, increase):
    print ("  <path d=\"M{} {} {}\" stroke=\"#000000\" stroke-width=\"0.35\" fill=\"none\" />".\
           format(x1, y1, increase))

def mark_of_sector (x, y, txt):
    print ("  <text")
    print ("    style=\"font-style:normal;font-weight:normal;font-size:3.5px;"\
           "font-family:sans-serif;fill:#000000;fill-opacity:1;stroke:none;"\
           "stroke-width:0.25;text-anchor:middle\"")
    print ("    x=\"{}\" y=\"{}\" >".format(x, y))
    print (txt)
    print ("  </text>")

def format_and_dimensions (txt, txt_aligment, x, y):
    print ("  <!-- Format and dimension information -->")
    print ("  <text")
    print ("    style=\"font-style:normal;font-weight:normal;font-size:3.5px;"\
           "font-family:sans-serif;fill:#000000;fill-opacity:1;stroke:none;"\
           "stroke-width:0.25;text-anchor:{}\"".format(txt_aligment))
    print ("    x=\"{}\" y=\"{}\" >".format(x, y))
    print (txt)
    print ("  </text>")



# Subroutines and functions for title box
# ***************************************
def title_box_borders (element_comment, path_construction, width):
    print ("  <!-- " + element_comment + " -->")
    print ("  <path")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:"+width+ \
           ";stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"")
    print ("    d=\""+path_construction+"\" />")

def title_box_text (x, y, size, text):
    print ("  <text")
    print ("    style=\"font-style:normal;font-weight:normal;font-size:{}px;font-family:sans-serif;"\
           "fill:#000000;fill-opacity:1;stroke:none;stroke-width:0.25;text-anchor:start\"".format(size))
    print ("    x=\"{}\" y=\"{}\" >".format(x, y))
    print (text)
    print ("  </text>")

def title_box_edit (x, y, size, entryName, text):
    print ("  <text")
    print ("    style=\"font-style:normal;font-weight:normal;font-size:{}px;font-family:sans-serif;"\
           "fill:#000000;fill-opacity:1;stroke:none;stroke-width:0.25;text-anchor:start\"".format(size))
    print ("    freecad:editable=\""+entryName+"\" x=\"{}\" y=\"{}\" >".format(x, y))
    print ("    <tspan>"+text+"</tspan>")
    print ("  </text>")

def title_box_projection_symbol (x, y):
    # 0,0                                  h35
    # +-------------------------------------+
    # |                                     | empty v5
    # |        ----+          ---|---       |
    # |     ---    |        /   -.-   \     |
    # |   |        |       /  /  |  \  \    |
    # | --- . --- . --- . --- . --- . ---   | centerine v10
    # |   |        |       \  \  |  /  /    |
    # |     ---    |        \   -.-   /     |
    # |        ----+          ---|---       |
    # |                                     | empty v5
    # +-------------------------------------+ v20
    #   5    10        5   diameter5/10  5
    print ("<!-- Projection symbol - first angle symbol -->")
    # border around
    print ("<path")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.25;" \
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"")
    print ("    d=\"M{0} {1} h35 v20 h-35 z\" />".format(x, y))
    # hotizontal center line
    print ("<path")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.25;" \
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:5,1.5,1.5,1.5\"")
    print ("    d=\"M{0} {1} h30\" />".format(x+2.5, y+10))
    # vertical center line
    print ("<path")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.25;" \
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:5,1.5,1.5,1.5\"")
    print ("    d=\"M{0} {1} v15\" />".format(x+25, y+2.5))
    # side view
    print ("<path")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.5;" \
           "stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;stroke-dasharray:none\"")
    print ("    d=\"M{0} {1} l10 -2.5 l0 10 l-10 -2.5 z\" />".format(x+5, y+7.5))
    # front view
    print ("<circle")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.5;" \
           "stroke-opacity:1;stroke-dasharray:none\"")
    print ("     cx=\"{0}\" cy=\"{1}\" r=\"5\"/>".format(x+25, y+10))
    print ("<circle")
    print ("    style=\"fill:#ffffff;fill-opacity:0;stroke:#000000;stroke-width:0.5;" \
           "stroke-opacity:1;stroke-dasharray:none\"")
    print ("     cx=\"{0}\" cy=\"{1}\" r=\"2.5\"/>".format(x+25, y+10))
#
#
# int main (int arg_c, char **arg_v) {
# ************************************
# Ok, I'm kidding. Main program body starts here.
#
# Command line arguments - if there is no expected number of arguments, print help and exit.
if len(sys.argv) != 9:
    help_report()
    exit (0)
#
# Command line arguments - if there is calling for help, print help and exit.
for i, arg in enumerate(sys.argv):
    if arg == "help" or arg == "-help" or arg == "--help" or arg == "?" or arg == "-?" or arg == "--?":
        help_report ()
        exit (0)
#
# Command line arguments - assign arguments to variables.
# No checks for correct values or correct order of arguments - this is flaw,
# but I do not want to make this script so complicated...
# script_name = sys.argv[0]
paper_format = sys.argv[1]
paper_units  = sys.argv[2]
paper_width  = float(sys.argv[3])
paper_height = float(sys.argv[4])
legal_owner1 = sys.argv[5]
legal_owner2 = sys.argv[6]
legal_owner3 = sys.argv[7]
legal_owner4 = sys.argv[8]
#
#
# Head of XML file
# ****************
print ("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>")
#
#
# <svg> tag opening
# *****************
print ("<svg")
print ("  xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"")
print ("  xmlns:freecad=\"http://www.freecad.org/wiki/index.php?title=Svg_Namespace\"")
# print ("  xmlns:xlink=\"http://www.w3.org/1999/xlink\"")
print ("  width=\"{}{}\"".format(paper_width, paper_units))
print ("  height=\"{}{}\"".format(paper_height, paper_units))
print ("  viewBox=\"0 0 {} {}\">".format(paper_width, paper_height))
print ("")
#
#
# First make a borders around drawing area according ISO 5457 - more less
# ***********************************************************************
#
# Some important calculations at the begining
# Center of drawing area for center marks and for sectors
drawing_h_center = (paper_width + 20. - 10.) / 2
drawing_v_center = (paper_height + 10. - 10.) / 2
x_first_sector_delimiter = drawing_h_center - ((math.ceil((drawing_h_center - 20.)/50.)) - 1) * 50.
y_first_sector_delimiter = drawing_v_center - ((math.ceil((drawing_v_center - 10.)/50.)) - 1) * 50.

# Corner marks
corner_mark ("upper left corner mark", "M0 0 h10 v5 h-5 v5 h-5 z")
corner_mark ("upper right corner mark", "M{} 0 v10 h-5 v-5 h-5 v-5 z".format(paper_width))
corner_mark ("lower left corner mark", "M0 {} h10 v-5 h-5 v-5 h-5 z".format(paper_height))
corner_mark ("lower right corner mark", "M{} {} h-10 v-5 h5 v-5 h5 z".format(paper_width, paper_height))

# borders of drawing area
borders_of_drawing_area (15, 5, paper_width-5, paper_height-5, 0.35, "outside borders")
borders_of_drawing_area (20, 10, paper_width-10, paper_height-10, 0.7, "inside borders")

# center marks of drawing area
center_mark ("top center mark", "M{} 5 v15".format(drawing_h_center))
center_mark ("bottom center mark", "M{} {} v-15".format(drawing_h_center, paper_height-5))
center_mark ("left center mark", "M15 {} h15".format(drawing_v_center))
center_mark ("right center mark", "M{} {} h-15".format(paper_width-5, drawing_v_center))

print ("  <!-- horizontal delimiters of drawing sectors (A, B, ...) -->")
letter_list = ["A", "B", "C", "D", "E", "F", "G", "H", "J", "K", "L", "M", \
               "N", "P", "Q", "R", "S", "T", "U", "V", "W", "X", "Y", "Z"]
y_tmp = y_first_sector_delimiter
i_tmp = 0
# first marks of sector
# Format A4 has an exception: only right letters
if paper_format != "A4":
    mark_of_sector (17.5, (y_tmp+5.)/2., letter_list[i_tmp])
mark_of_sector (paper_width-7.5, (y_tmp+5.)/2., letter_list[i_tmp])
while y_tmp < paper_height-10:
    # left delimiter
    delimiter_of_sectors (15, y_tmp, "h5")
    # right delimiter
    delimiter_of_sectors (paper_width-5, y_tmp, "h-5")
    # increase number of sector
    i_tmp += 1
    # Left and right letters of sector
    if y_tmp + 50 <= paper_height - 10:
        # normal sector 50 mm height. The letter will be 25 mm below delimiter
        # Format A4 has an exception: only right letters
        if paper_format != "A4":
            mark_of_sector (17.5, y_tmp+25, letter_list[i_tmp])
        mark_of_sector (paper_width-7.5, y_tmp+25, letter_list[i_tmp])
    else:
        # short last sector. The letter should be in a center of the sector
        # Format A4 has an exception: only right letters
        if paper_format != "A4":
            mark_of_sector (17.5, (y_tmp+paper_height-10.)/2., letter_list[i_tmp])
        mark_of_sector (paper_width-7.5, (y_tmp+paper_height-10.)/2., letter_list[i_tmp])        
    # move the counter/y position
    y_tmp += 50
print ("")

print ("  <!-- vertical delimiters of drawing sectors (1, 2, ...) -->")
x_tmp = x_first_sector_delimiter
i_tmp = 1
mark_of_sector ((x_tmp+20.)/2., 9, "{}".format(i_tmp))
# Format A4 has an exception: only upper nubers
if paper_format != "A4":
    mark_of_sector ((x_tmp+20.)/2., paper_height - 6, "{}".format(i_tmp))
while x_tmp < paper_width-10:
    # upper delimiter
    delimiter_of_sectors (x_tmp, 5, "v5")
    delimiter_of_sectors (x_tmp, paper_height-10, "v5")
    # move the i_tmp counter
    i_tmp += 1
    # left and right marks of sector
    if x_tmp + 50 <= paper_width - 10:
        # normal sector 50 mm width. The number will be 25 mm right of delimiter
        mark_of_sector (x_tmp+25, 9, "{}".format(i_tmp))
        # Format A4 has an exception: only upper nubers
        if paper_format != "A4":
            mark_of_sector (x_tmp+25, paper_height - 6, "{}".format(i_tmp))
    else:
        # short last sector. The number should be in a center of the sector
        mark_of_sector ((x_tmp+paper_width-10.)/2., 9, "{}".format(i_tmp))
        # Format A4 has an exception: only upper nubers
        if paper_format != "A4":
            mark_of_sector ((x_tmp+paper_width-10.)/2., paper_height - 6, "{}".format(i_tmp))
    # move the counter/x position
    x_tmp += 50

format_and_dimensions ("{} - {}x{}{}".format(paper_format, paper_width, paper_height, paper_units), \
                       "start", 12, 3.75)
format_and_dimensions ("{} - {}x{}{}".format(paper_format, paper_width, paper_height, paper_units), \
                       "end", paper_width -12, paper_height - 1.25)
#
#
#
# Now make a tilte box with texts according ISO 7200 - more less
# **************************************************************
#
# local coordinates of title box
#   h0 = horizontal 0 mm .. h180 = horizontal 180 mm
#   v0 = vertical 0 mm .. v40 = vertical 40 mm
#
# h0           h36             h72                     h108                    h144       h162      h180
# +------------+---------------+-----------------------+-----------------------+----------+---------+ v00
# | Resp. Dep. | Tech.Ref.     | Creator               | Approval person       | Format   | Scale   |
# | ---        | ---           | ---                   | ---                   | A4       | 1:1     |
# +------------+-----------+---+-----------------------+-----+-----------------+----------+---------+ v10
# | Legal owner            | Document type                   | Document status                      |
# |                        | ---                             | Draft                                |
# | ---                    |---------------------------------+--------------------------------------+ v20
# | ---                    | Name of document, supplem. name | Identification number                |
# | ---                    |                                 | ---                                  |
# | ---                    | ---                             +------+---------------+-------+-------+ v30
# |                        | ---                             | Rev. | Date of issue | Lang. | Sheet |
# |                        |                                 | ---  | ---           | EN    | 1/1   |
# +------------------------+---------------------------------+------+---------------+-------+-------+ v40
# h0                       h60                               h120   h132            h156    h168    h180
#
# Global definitions for title box
title_box_width = 180
title_box_height = 40
title_box_units = "mm"
# Absolute coordinates of upper left corner of the title box
x0tb = paper_width - 10 - 180
y0tb = paper_height - 10 - 40
#
print ("")
print ("")
print ("  <!-- Title box -->")
# Title box rectangle - 0.7 mm thick
x0 = x0tb
y0 = y0tb
title_box_borders ("Title block borders", "M{0} {1} h{2} v{3} h-{2} z".\
                   format(x0, y0, title_box_width, title_box_height), "0.7")
#
# Responsible department
x0 = x0tb
y0 = y0tb
title_box_borders ("Responsible department", "M{} {} h36 v10 h-36 z".\
                   format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Responsible department") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Odpovědné oddělení") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "RespDep", "---")
#
# Technical Reference
x0 = x0tb + 36
y0 = y0tb
title_box_borders ("Technical reference", "M{} {} h36 v10 h-36 z".\
                   format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Technical reference") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Technický referent") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "TechRef", "---")
#
# Creator
x0 = x0tb + 72
y0 = y0tb
title_box_borders ("Creator", "M{} {} h36 v10 h-36 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Creator") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Vyhotovil") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "Creator", "---")
#
# Approval person
x0 = x0tb + 108
y0 = y0tb
title_box_borders ("Creator", "M{} {} h36 v10 h-36 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Approval person") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Schválil") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "ApprPerson", "---")
#
# Format
x0 = x0tb + 144
y0 = y0tb
title_box_borders ("Format", "M{} {} h18 v10 h-18 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Format") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Formát") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DrwFormat", paper_format)
#
# Scale
x0 = x0tb + 162
y0 = y0tb
title_box_borders ("Scale", "M{} {} h18 v10 h-18 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Scale") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Měřítko") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DrwScal", "1:1")
#
# Legal Owner
x0 = x0tb
y0 = y0tb + 10
title_box_borders ("Legal Owner", "M{} {} h60 v30 h-60 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Legal Owner") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Zákonný vlastník") # cs
title_box_edit (x0 +1, y0 +3.5  +5, 3.5, "OwnerLine1", legal_owner1)
title_box_edit (x0 +1, y0 +3.5 +10, 3.5, "OwnerLine2", legal_owner2)
title_box_edit (x0 +1, y0 +3.5 +15, 3.5, "OwnerLine3", legal_owner3)
title_box_edit (x0 +1, y0 +3.5 +20, 3.5, "OwnerLine4", legal_owner4)
#
# Document type
x0 = x0tb + 60
y0 = y0tb + 10
title_box_borders ("Document type", "M{} {} h60 v10 h-60 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Document type") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Druh dokumentu") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DocType", "---")
#
# Name of document, supplementary name
x0 = x0tb + 60
y0 = y0tb + 20
title_box_borders ("Document type", "M{} {} h60 v20 h-60 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0  +3.5, 2.5, "Document name, supplementary name") # en
# title_box_text (x0 +1, y0  +3.5, 2.5, "Název, doplňující název") # cs
title_box_edit (x0 +1, y0  +8.5, 3.5, "DocName", "---")
title_box_edit (x0 +1, y0 +13.5, 3.5, "DocSuppName", "---")
#
# Document status
x0 = x0tb + 120
y0 = y0tb + 10
title_box_borders ("Document status", "M{} {} h60 v10 h-60 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Document status") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Status dokumentu") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DocStatus", "Draft")
#
# Identification number
x0 = x0tb + 120
y0 = y0tb + 20
title_box_borders ("Identification number", "M{} {} h60 v10 h-60 z".\
                     format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Identification number") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Číslo dokumentu") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "IDnumber", "---")
#
# Revision
x0 = x0tb + 120
y0 = y0tb + 30
title_box_borders ("Revision", "M{} {} h12 v10 h-12 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Revision") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Revize") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DocRev", "---")
#
# Date of issue
x0 = x0tb + 132
y0 = y0tb + 30
title_box_borders ("Date of issue", "M{} {} h24 v10 h-24 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Date of issue") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Datum vydání") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "DateOfIssue", "---")
#
# Language
x0 = x0tb + 156
y0 = y0tb + 30
title_box_borders ("Language", "M{} {} h12 v10 h-12 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Lang.") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "Jazyk") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "Language", "EN") # en
# title_box_edit (x0 +1, y0 +8.5, 3.5, "Language", "CS") # cs
#
# Sheet
x0 = x0tb + 168
y0 = y0tb + 30
title_box_borders ("Sheet/Sheets", "M{} {} h12 v10 h-12 z".format(x0, y0), "0.35")
title_box_text (x0 +1, y0 +3.5, 2.5, "Sheet") # en
# title_box_text (x0 +1, y0 +3.5, 2.5, "List") # cs
title_box_edit (x0 +1, y0 +8.5, 3.5, "SheetSheets", "1/1") # en
# title_box_edit (x0 +1, y0 +8.5, 3.5, "ListListů", "1/1") # cs
#
# Projection symbol above the title box
# 0,0                                  h35
# +-------------------------------------+
# |                                     | empty v5
# |        ----+          ---|---       |
# |     ---    |        /   -.-   \     |
# |   |        |       /  /  |  \  \    |
# | --- . --- . --- . --- . --- . ---   | centerine v10
# |   |        |       \  \  |  /  /    |
# |     ---    |        \   -.-   /     |
# |        ----+          ---|---       |
# |                                     | empty v5
# +-------------------------------------+ v20
#   5    10        5   diameter5/10  5
# x0, y0 are coordinates of upper left point
x0 = x0tb + title_box_width - 35 - 1.5
y0 = y0tb - 20 - 1.5
title_box_projection_symbol (x0, y0)

# end of <svg> tag
# ****************
print ("</svg>")


# End of program
# **************
exit(0)
